'use strict';

var inertia = require('@inertiajs/inertia');
var core = require('@formkit/core');

const loadingMessage = core.createMessage({
    key: 'loading',
    visible: false,
    value: true,
});
const injectNode = (node, options) => {
    const addonOptions = {};
    addonOptions.onCancelToken = ({ cancel }) => {
        if (options?.onCancelToken)
            return options.onCancelToken(cancel, node);
    };
    addonOptions.onBefore = (visit) => {
        if (options?.onBefore)
            return options.onBefore(visit, node);
    };
    addonOptions.onStart = (visit) => {
        if (!options?.disableLoading)
            node.store.set(loadingMessage);
        if (!options?.disableDisabled)
            node.props.disabled = true;
        if (options?.onStart)
            options.onStart(visit, node);
    };
    addonOptions.onProgress = (progress) => {
        if (!options?.disableProgress && node.context)
            node.context.attrs = { 'data-progress': progress?.total };
        if (options?.onProgress)
            options.onProgress(progress, node);
    };
    addonOptions.onFinish = (visit) => {
        if (!options?.disableLoading)
            node.store.remove('loading');
        if (!options?.disableDisabled)
            node.props.disabled = false;
        if (!options?.disableProgress && node.context && node.context.attrs['data-progress'])
            delete node.context.attrs['data-progress'];
        if (options?.onFinish)
            options.onFinish(visit, node);
    };
    addonOptions.onCancel = () => {
        if (options?.onCancel)
            options.onCancel(node);
    };
    addonOptions.onSuccess = (page) => {
        if (options?.onSuccess)
            options.onSuccess(page, node);
    };
    addonOptions.onError = (errors) => {
        if (options?.onError)
            return options.onError(errors, node);
        if (!options?.disableErrors)
            node.setErrors([], errors);
    };
    return addonOptions;
};
const useInertia = (formNode) => {
    return {
        visit: (url, options) => inertia.Inertia.visit(url, injectNode(formNode, options)),
        get: (url, data, options) => inertia.Inertia.get(url, data, injectNode(formNode, options)),
        post: (url, data, options) => inertia.Inertia.post(url, data, injectNode(formNode, options)),
        put: (url, data, options) => inertia.Inertia.put(url, data, injectNode(formNode, options)),
        patch: (url, data, options) => inertia.Inertia.patch(url, data, injectNode(formNode, options)),
        delete: (url, options) => inertia.Inertia.delete(url, injectNode(formNode, options)),
        reload: (options) => inertia.Inertia.reload(injectNode(formNode, options)),
    };
};

const plugin = (node) => {
    if (node.props.type !== 'form' || !node.context)
        return false;
    if (node.context)
        node.context.inertia = useInertia(node);
};

exports.plugin = plugin;
exports.useInertia = useInertia;
//# sourceMappingURL=index.cjs.js.map
